<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation>Przenieś do kosza</translation>
    </message>
</context>
<context>
    <name>dock::AppItem</name>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Odepnij</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Przypnij</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Wymuś zakończenie</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Zamknij wszystkie</translation>
    </message>
</context>
<context>
    <name>dock::DockGlobalElementModel</name>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Odepnij</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Przypnij</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Wymuś zakończenie</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Zamknij wszystkie</translation>
    </message>
</context>
<context>
    <name>dock::TaskManager</name>
    <message>
        <source>%1 files</source>
        <translation>%1 plików</translation>
    </message>
</context>
</TS>